﻿using System;
using System.Windows.Forms;

using DevExpress.XtraEditors;
using DevExpress.XtraEditors.Repository;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            this.showInputBoxButton.Click += showInputBoxButton_Click;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 입력 상자 표시 버튼 클릭시 처리하기 - showInputBoxButton_Click(sender, e)

        /// <summary>
        /// 입력 상자 표시 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void showInputBoxButton_Click(object sender, EventArgs e)
        {
            DateEdit dateEdit = new DateEdit();

            dateEdit.Properties.CalendarView  = CalendarView.TouchUI;
            dateEdit.Properties.Mask.EditMask = "yyyy-MM-dd";

            XtraInputBoxArgs xtraInputBoxArgs = new XtraInputBoxArgs();

            xtraInputBoxArgs.Owner              = this;
            xtraInputBoxArgs.Caption            = "선적 옵션";
            xtraInputBoxArgs.Prompt             = "배송일";
            xtraInputBoxArgs.DefaultButtonIndex = 0;
            xtraInputBoxArgs.Editor             = dateEdit;
            xtraInputBoxArgs.DefaultResponse    = DateTime.Now.Date.AddDays(3);

            xtraInputBoxArgs.Showing += xtraInputBoxArgs_Showing;

            DateTime? result = (DateTime?)XtraInputBox.Show(xtraInputBoxArgs);

            if(result != null)
            {
                XtraMessageBox.Show(this, result.ToString(), "INFORMATION", MessageBoxButtons.OK, MessageBoxIcon.Information);
            }
        }

        #endregion
        #region XTRA 입력 상자 인자 표시시 처리하기 - xtraInputBoxArgs_Showing(sender, e)

        /// <summary>
        /// XTRA 입력 상자 인자 표시시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void xtraInputBoxArgs_Showing(object sender, XtraMessageShowingArgs e)
        {
            e.Form.Icon = this.Icon;
        }

        #endregion
    }
}